Module: Devise::Models::Invitable::ClassMethods

Defined in:
lib/devise_invitable/model.rb

Instance Method Summary collapse

Instance Method Details

#_invite(attributes = {}, invited_by = nil, &block) ⇒ Object

Attempt to find a user by it’s email. If a record is not found, create a new user and send invitation to it. If user is found, returns the user with an email already exists error. If user is found and still have pending invitation, email is resend unless resend_invitation is set to false Attributes must contain the user email, other attributes will be set in the record



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/devise_invitable/model.rb', line 210

def _invite(attributes={}, invited_by=nil, &block)
  invite_key_array = invite_key_fields
  attributes_hash = {}
  invite_key_array.each do |k,v|
    attributes_hash[k] = attributes.delete(k)
  end

  invitable = find_or_initialize_with_errors(invite_key_array, attributes_hash)
  invitable.assign_attributes(attributes, :as => inviter_role(invited_by))
  invitable.invited_by = invited_by

  invitable.skip_password = true
  invitable.valid? if self.validate_on_invite
  if invitable.new_record?
    invitable.errors.clear if !self.validate_on_invite and invitable.invite_key_valid?
  elsif !invitable.invited_to_sign_up? || !self.resend_invitation
    invite_key_array.each do |key|
      invitable.errors.add(key, :taken)
    end
  end

  if invitable.errors.empty?
    yield invitable if block_given?
    mail = invitable.invite!
  end
  [invitable, mail]
end

#accept_invitation!(attributes = {}) ⇒ Object

Attempt to find a user by it’s invitation_token to set it’s password. If a user is found, reset it’s password and automatically try saving the record. If not user is found, returns a new user containing an error in invitation_token attribute. Attributes must contain invitation_token, password and confirmation



259
260
261
262
263
264
265
266
267
# File 'lib/devise_invitable/model.rb', line 259

def accept_invitation!(attributes={})
  invitable = find_or_initialize_with_error_by(:invitation_token, attributes.delete(:invitation_token))
  invitable.errors.add(:invitation_token, :invalid) if invitable.invitation_token && invitable.persisted? && !invitable.valid_invitation?
  if invitable.errors.empty?
    invitable.attributes = attributes
    invitable.accept_invitation!
  end
  invitable
end

#after_invitation_accepted(*args, &blk) ⇒ Object



279
280
281
# File 'lib/devise_invitable/model.rb', line 279

def after_invitation_accepted(*args, &blk)
  set_callback(:invitation_accepted, :after, *args, &blk)
end

#before_invitation_accepted(*args, &blk) ⇒ Object

Callback convenience methods



275
276
277
# File 'lib/devise_invitable/model.rb', line 275

def before_invitation_accepted(*args, &blk)
  set_callback(:invitation_accepted, :before, *args, &blk)
end

#invitation_tokenObject

Generate a token checking if one does not already exist in the database.



270
271
272
# File 'lib/devise_invitable/model.rb', line 270

def invitation_token
  generate_token(:invitation_token)
end

#invite!(attributes = {}, invited_by = nil, &block) ⇒ Object



244
245
246
247
# File 'lib/devise_invitable/model.rb', line 244

def invite!(attributes={}, invited_by=nil, &block)
  invitable, mail = _invite(attributes, invited_by, &block)
  invitable
end

#invite_key_fieldsObject

Return fields to invite



195
196
197
198
199
200
201
202
# File 'lib/devise_invitable/model.rb', line 195

def invite_key_fields
  if invite_key.is_a? Hash
    invite_key.keys
  else
    ActiveSupport::Deprecation.warn("invite_key should be a hash like {#{invite_key.inspect} => /.../}")
    Array(invite_key)
  end
end

#invite_mail!(attributes = {}, invited_by = nil, &block) ⇒ Object



249
250
251
252
# File 'lib/devise_invitable/model.rb', line 249

def invite_mail!(attributes={}, invited_by=nil, &block)
  invitable, mail = _invite(attributes, invited_by, &block)
  mail
end

#inviter_role(inviter) ⇒ Object

Override this method if the invitable is using Mass Assignment Security and the inviter has a non-default role.



240
241
242
# File 'lib/devise_invitable/model.rb', line 240

def inviter_role(inviter)
  :default
end